TEMPLATES = {
    "record": "templates/record.py.jinja2",
    "record-metadata": "templates/record_metadata.py.jinja2",
    "permissions": "templates/permissions.py.jinja2",
    "record-search-options": "templates/invenio_record_search_options.py.jinja2",
    "service-config": "templates/service_config.py.jinja2",
    "service": "templates/service.py.jinja2",
    "marshmallow": "templates/marshmallow.py.jinja2",
    "record-dumper": "templates/record_dumper.py.jinja2",
    "ui-serializer": "templates/ui_serializer.py.jinja2",
    "resource-config": "templates/resource_config.py.jinja2",
    "resource": "templates/resource.py.jinja2",
    "api-views": "templates/api_views.py.jinja2",
    "app-views": "templates/app_views.py.jinja2",
    "version": "templates/version.py.jinja2",
    "config": "templates/config.py.jinja2",
    "ext": "templates/ext.py.jinja2",
    "proxies": "templates/proxies.py.jinja2",
    "record-facets": "templates/invenio_record_facets.py.jinja2",
    "pid-provider": "templates/pid_provider.py.jinja2",
    # utils and included
    "ext-resource": "templates/ext_resource.py.jinja2",
    "edtf-interval-record-dumper": "templates/edtf_interval_record_dumper.py.jinja2",
    "record-item": "templates/record_item.py.jinja2",
    "record-list": "templates/record_list.py.jinja2",
}
